*=$0A00   ; start address (use SYS... to start)

;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;                      INITIALIZE (main program: interrupts, charset, etc.)
;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

INIT            LDA #$80                ;DISABLE case changes caused by pressing CBM+shift
                STA $0291               ;

                JSR LIGHTGUN_INIT       ;

                ;define raster interrupt for all our timing specific routines
                ;---------------------------------------------------------------    
SOUND_INIT      LDA #SOUNDFX_FIRSTTIME  ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT        ;initialise SID (this address depends on the SID being played)

RASTERINT_INIT  SEI                     ;prevent an non maskable interrupt     
                LDA #%01111111          ;
                STA $DC0D               ;"Switch off" all interrupts signals from CIA-1
                AND $D011               ;
                STA $D011               ;Clear most significant bit in VIC's raster register
                LDA #250                ;Set the raster line number where interrupt should occur 
                STA $D012               ;this value will be changed in the interrupt handler, so the
                LDA #<IRQ               ;initial value does not really matter
                STA $0314               ;
                LDA #>IRQ               ;
                STA $0315               ;Set the interrupt vector to point to interrupt service routine below
                LDA #%00000001          ;
                STA $D01A               ;Enable raster interrupt signals from VIC
                CLI                     ;enable non maskable interrupt        


                        
SPRITE_INIT     LDA #$80                ;sprite trigger
                STA $07F8               ;set pointer for sprite-0 ($80 => $2000)

                LDA #$02                ;
                STA $D027               ;sprite 0 color (aka color-3 or bitpair '11') the sprite's only individual color

                LDA #%00000000          ;
                STA $D010               ;sprite 0-7 9th bit of X-coordinate
                LDA #%00000001          ;
                STA $D015               ;sprite 0-7 enable/disable register (1=enable)
                LDA #%00000000          ;
                STA $D017               ;sprite 0-7 expand in Y direction register (1=enable)
                STA $D01D               ;sprite 0-7 expand in X direction register (1=enable)
                    
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;                                             MAIN
;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

MAIN            LDA #SOUNDFX_MUSIC      ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT        ;initialise SID (this address depends on the SID being played)
                JSR SHOW_BITMAP         ;

WAIT_FOR_REL    JSR SCAN_KEYRELEASE     ;wait until the keyboard is released (no key pressed)

WAIT_FOR_USER   JSR SCAN_KEYPRESS       ;
WFU_01          CMP #KEY_F3             ;
                BEQ SHOW_DOCS           ;
                CMP #KEY_F1             ;
                BNE WFU_02              ;
                JSR CALLIBRATE_LIGHTGUN ;
                JMP MAIN                ;after callibration return to the MAIN screen

WFU_02          JSR GET_LIGHTGUN_POS    ;show the user where he/she is pointing
        ;JSR CHECK_HAMMER        ;this routine will return with C=0 when nothing is pressed, C=1 when trigger is pressed
                JSR CHECK_TRIGGER       ;
                BCS GAME_INIT           ;trigger pulled, then start game

WFU_03          JMP WAIT_FOR_USER       ;

                ;...............................................................
SHOW_DOCS       JSR SHOW_NORMAL         ;
                LDA #1  ;11             ;0=black, 1=white, 5=green, 9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDX #0                  ;build the screen
                LDY #0                  ;
                JSR SET_CURSOR          ;
                LDA #<SCREEN_DOCS       ;set pointer to the text that defines the main-screen
                LDY #>SCREEN_DOCS       ;
                JSR PRINT_STRING        ;the print routine is called, so the pointed text is now printed to screen     

SHOW_DOCS_01    JSR GET_LIGHTGUN_POS    ;show the user where he/she is pointing
                JSR CHECK_TRIGGER       ;
                BCC SHOW_DOCS_01        ;stayhere untill trigger pulled
SHOW_DOCS_02    JSR CHECK_TRIGGER       ;
                BCS SHOW_DOCS_02        ;stayhere untill trigger released
                JMP MAIN                ;

                ;...............................................................

GAME_INIT       LDA #SOUNDFX_GAME_START ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT        ;initialise SID (this address depends on the SID being played)
                JSR SHOW_NORMAL         ;switch to character mode and select custom charset
                JSR CLEAR_QUADRANTS     ;print something on screen
                LDA #128                ;create a table of ... values that make the pattern
                STA TMP_1               ;get "random" value to determine which quadrant should light using a couple of registers
GAME_INIT_01    LDA $DC04               ;CIA#1  Timer A  Lo byte     
                EOR $DC05               ;CIA#1  Timer A  Hi byte 
                EOR $DD04               ;CIA#2  Timer A  Lo byte 
                ADC $DD05               ;CIA#2  Timer A  Hi byte 
                EOR $DD06               ;CIA#2  Timer B  Lo byte 
                EOR $DD07               ;CIA#2  Timer B  Hi byte, A now contains a random value 0-255
                AND #%00000011          ;
                CLC                     ;A now contains value 0-3
                ADC #01                 ;add 1 to gert a value 1-4 (indicating the quadrants)

                DEC TMP_1               ;
                LDY TMP_1               ;save value to table
                STA PATTERN_TABLE,Y     ;
                LDA TMP_1               ;
                BNE GAME_INIT_01        ;

                LDA #1                  ;init game variables
                STA PATTERN_PROGRESS    ;(this value is also the score)

                ;...............................................................

PATTERN_SHOW    LDA #%00000000          ;
                STA $D015               ;sprite 0-7 enable/disable register (1=enable)

                LDA #0                  ;
                STA PATTERN_SHOW_PNTR   ;

                JSR LONG_DELAY          ;wait a little for the music to end...
    
PATTERN_SHOW_01 JSR CLEAR_QUADRANTS     ;

                LDA PATTERN_SHOW_PNTR   ;check if the current pattern is fully shown (up to the point of the current progress)
                CMP PATTERN_PROGRESS    ;
                BEQ PATTERN_CHECK       ;when the pattern is shown, the check if the user can repeat it

                JSR DELAY               ;

                LDY PATTERN_SHOW_PNTR   ;read from table which quadrant should light up
                LDA PATTERN_TABLE,Y     ;
                CMP #127                ;end of table (the table is not longer then 128 values)
                BNE PATTERN_SHOW_02     ;
                JMP GAME_WINNER         ;yes, end of table, well this means only one thing... WE HAVE A WINNER!!!

PATTERN_SHOW_02 JSR LIGHT_QUADRANT      ;
                JMP PATTERN_SHOW_01     ;

                ;...............................................................

PATTERN_CHECK   LDA #%00000001          ;
                STA $D015               ;sprite 0-7 enable/disable register (1=enable)

                LDA #0                  ;
                STA PATTERN_CHECK_PNTR  ;

PATTERN_CH_00   JSR TIMEBAR_INIT        ;
PATTERN_CH_01   JSR TIMEBAR             ;
                LDA #10                 ;                
                STA TMP_1               ;
PATTERN_CH_02   LDA #255                ;                
                STA TMP_2               ;
PATTERN_CH_03   JSR GET_LIGHTGUN_POS    ;show the user where he/she is pointing (also acts as the delay)
                JSR CHECK_TRIGGER       ;
                BCS PATTERN_CH_04       ;trigger pulled, now check what we've hit
                DEC TMP_2               ;
                BNE PATTERN_CH_03       ;
                DEC TMP_1               ;
                BNE PATTERN_CH_02       ;

                LDA TIMECOUNT           ;has the time expired yet?
                BEQ GAME_OVER           ;
                JMP PATTERN_CH_01       ;

PATTERN_CH_04   LDA #$00                ;calculate character position of sprite 0
                LDX #12                 ;additional offset in pixels for X (so we effectively use the centre of the sprite)
                LDY #10                 ;additional offset in pixels for Y (so we effectively use the centre of the sprite)
                JSR CALC_SPRITE_CR      ;it will return with a value in CHR_COLUMN and CHR_ROW
                JSR CALC_CHAR_ADDR      ;convert value in CHR_COLUMN and CHR_ROW to a character address
                LDY #$00                ;
                LDA (CHAR_ADDR),Y       ;
                SEC                     ;
                SBC #122                ;the characters we want to see in the Q1=123, Q2=124, Q3=125, Q4=126
                BEQ PATTERN_CH_01       ;false hit, user hit something else then the quadrants he/she was suppost to hit
                CMP #5                  ;
                BCS PATTERN_CH_01       ;false hit, user hit something else then the quadrants he/she was suppost to hit

                PHA                     ;save Quadrant value (stored in A) to stack
                JSR LIGHT_QUADRANT      ;
                PLA                     ;recover Quadrant value (stored in A) from stack

                LDY PATTERN_CHECK_PNTR  ;read from table which quadrant should light up
                CMP PATTERN_TABLE,Y     ;
                BNE GAME_OVER           ;

                INC PATTERN_CHECK_PNTR  ;
                LDA PATTERN_CHECK_PNTR  ;
                CMP PATTERN_PROGRESS    ;
                BNE PATTERN_CH_00       ;keep looping until all parts of the sequence are repeated OR the time expires

                INC PATTERN_PROGRESS    ;succes, game makes progress

                LDA #SOUNDFX_LEVEL_COMPLETE     ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT                ;initialise SID (this address depends on the SID being played)
                JMP PATTERN_SHOW                ;show the new pattern (1 step longer the the current pattern)

                ;...............................................................

GAME_OVER       LDA #SOUNDFX_GAME_OVER  ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT        ;initialise SID (this address depends on the SID being played)
                JSR SHOW_SCORE          ;show the players score
                JSR LONG_DELAY          ;wait a little for the music to end...
GAME_OVER_01    JSR GET_LIGHTGUN_POS    ;show the user where he/she is pointing (also acts as the delay)
                ;JSR CHECK_HAMMER       ;this routine will return with C=0 when nothing is pressed, C=1 when trigger is pressed
                JSR CHECK_TRIGGER       ;
                BCC GAME_OVER_01        ;trigger pulled, then start game
                JMP MAIN                ;start all over...


                ;...............................................................

GAME_WINNER     JSR SHOW_SCORE          ;show the players score
                LDA #SOUNDFX_WINNER     ;0=first tune, 1=second tune, 2=third tune, etc
                JSR SOUNDFX_INIT        ;initialise SID (this address depends on the SID being played)
                JSR CLEARSCREEN         ;
                LDA #5                  ;0=black, 1=white, etc.
                STA COL_PRINT           ;set printing color
                LDX #0                  ;write the instructions
                LDY #10                 ;
                JSR SET_CURSOR          ;
                LDA #<TXT_WINNER        ;set pointer to the text that defines the callibration-screen
                LDY #>TXT_WINNER        ;
                JSR PRINT_STRING        ;the print routine is called, so the pointed text is now printed to screen   
GAME_WIN_01     JMP GAME_WIN_01         ;endless loop!!!

;------------------------------------------------------------------------------------------------------------------

SHOW_SCORE      JSR CLEARSCREEN         ;
                LDA #5                  ;0=black, 1=white, etc.
                STA COL_PRINT           ;set printing color
                LDX #0                  ;write the instructions
                LDY #10                 ;
                JSR SET_CURSOR          ;
                LDA #<TXT_SCORE         ;set pointer to the text that defines the callibration-screen
                LDY #>TXT_SCORE         ;
                JSR PRINT_STRING        ;the print routine is called, so the pointed text is now printed to screen     

                LDX #23                 ;
                LDY #10                 ;
                JSR SET_CURSOR          ;
                LDA PATTERN_PROGRESS    ;Y-register must contain value to be printed
                JSR PRINT_DEC           ;the print routine is called
                RTS


TXT_SCORE    ;0123456789012345678901234567890123456789
        TEXT '        your score is:                  '
        TEXT '                                        '
        TEXT '        better luck next time           '
        BYTE 0

TXT_WINNER   ;0123456789012345678901234567890123456789
        TEXT '          max score reached             '
        TEXT '           you beat simon!              '
        BYTE 0


          
PATTERN_SHOW_PNTR       BYTE 0
PATTERN_CHECK_PNTR      BYTE 0
PATTERN_PROGRESS        BYTE 0
PATTERN_TABLE           BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                        BYTE 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
;------------------------------------------------------------------------------------------------------------------
;light a quadrant
;Call example:  LDA #1                  ;light's up quadrant 1
;               JSR LIGHT_QUADRANT      ;
;..................................................................................................................
LIGHT_QUADRANT
Q1              CMP #1                  ;
                BNE Q2                  ;
                JSR Q1_ACTIVE           ;activate quadrant-1
                JMP Q_DONE              ;

Q2              CMP #2                  ;
                BNE Q3                  ;
                JSR Q2_ACTIVE           ;activate quadrant-2
                JMP Q_DONE              ;

Q3              CMP #3                  ;
                BNE Q4                  ;
                JSR Q3_ACTIVE           ;activate quadrant-3
                JMP Q_DONE              ;

Q4              CMP #4                  ;
                BNE Q_ERROR             ;
                JSR Q4_ACTIVE           ;activate quadrant-4
                JMP Q_DONE              ;

Q_ERROR
Q_DONE          INC PATTERN_SHOW_PNTR   ;increase length of the pattern

                JSR DELAY               ;
                
CLEAR_QUADRANTS LDA #1  ;11                  ;0=black, 1=white, 5=green, 9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDX #0                  ;build the screen
                LDY #0                  ;
                JSR SET_CURSOR          ;
                LDA #<SCREEN_GAME       ;set pointer to the text that defines the main-screen
                LDY #>SCREEN_GAME       ;
                JSR PRINT_STRING        ;the print routine is called, so the pointed text is now printed to screen    

                LDA #5  ;11                  ;0=black, 1=white, 5=green, 9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDX #14                 ;
                LDY #13                 ;
                JSR SET_CURSOR          ;
                LDA PATTERN_PROGRESS    ;Y-register must contain value to be printed
                JSR PRINT_DEC           ;the print routine is called

                RTS  
;------------------------------------------------------------------------------------------------------------------
;These routines enable the colors of the quadrants of the game SIMON to disable
;the colors, simply redraw the main screen in the desired (default) color.
;The quadrants are defines as:  Q2 | Q1 (just as the teachers tought us in match class).
;                               ---+---
;                               Q3 | Q4
;
;Call example:  JSR Q1_ACTIVE           ;light up Qudrant 1 of the SIMON game
;..................................................................................................................

Q1_ACTIVE       LDA #2                  ;0=black, 1=white, 2=red, 5=green, 6=blue, 7=yellow,  9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDA #123                ;
                JSR RECOLOR             ;
                LDA #$20                ;
                JSR SOUND_TONE          ;
                RTS                     ;

Q2_ACTIVE       LDA #5                  ;0=black, 1=white, 2=red, 5=green, 6=blue, 7=yellow,  9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDA #124                ;
                JSR RECOLOR             ;
                LDA #$30                ;
                JSR SOUND_TONE          ;
                RTS                     ;

Q3_ACTIVE       LDA #7                  ;0=black, 1=white, 2=red, 5=green, 6=blue, 7=yellow,  9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDA #125                ;
                JSR RECOLOR             ;
                LDA #$40                ;
                JSR SOUND_TONE          ;
                RTS                     ;

Q4_ACTIVE       LDA #6                  ;0=black, 1=white, 2=red, 5=green, 6=blue, 7=yellow,  9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDA #126                ;
                JSR RECOLOR             ;
                LDA #$50                ;
                JSR SOUND_TONE          ;
                RTS                     ;

;------------------------------------------------------------------------------------------------------------------
;generate a sound to indicate the changed field
;Call example:  
;               LDA #$50                ;
;               JSR SOUND_TONE          ;
;..................................................................................................................
SOUND_TONE      PHA                             ;
                LDA #$10                        ;stop the sound (if not already stopped)
                STA $D404                       ;
                LDA #$0F                        ;FILTER MODE AND VOLUME 
                STA $D418                       ;
                LDA #$00                        ;VOICE 1 ADSR
                STA $D405                       ;attack, decay
                LDA #$F0                        ;
                STA $D406                       ;sustain, release
                PLA                             ;
                STA $D401                       ;
                LDA #$20                        ;VOICE 1 PULSE WAVEFORM WIDTH, LO-HI BYTE 
                STA $D400                       ;
                LDA #$11                        ;start the sound
                STA $D404                       ;

                JSR DELAY                       ;
                LDA #$10                        ;stop the sound, this triggers the release of sound as defined earlier
                STA $D404                       ;
                RTS                             ;

;..................................................................................................................
SOUND_TICK      LDA #$0F                        ;FILTER MODE AND VOLUME 
                STA $D418                       ;
                LDA #$00                        ;VOICE 1 ADSR
                STA $D405                       ;attack, decay
                LDA #$F0                        ;
                STA $D406                       ;sustain, release
                LDA #55                         ;
                STA $D401                       ;
                LDA #$20                        ;VOICE 1 PULSE WAVEFORM WIDTH, LO-HI BYTE 
                STA $D400                       ;
                LDA #$11                        ;start the sound
                STA $D404                       ;
                LDY #1                          ;
                JSR DELAY_LP1                   ;
                LDA #$10                        ;stop the sound, this triggers the release of sound as defined earlier
                STA $D404                       ;
                RTS                             ;

;------------------------------------------------------------------------------------------------------------------
;This delay routine s to be used for duration of the tone, the time the color is visible, time between colors, etc.
;Call example:
;               JSR DELAY
;..................................................................................................................
DELAY           LDY #$4F                        ;
DELAY_LP1       LDX #$FF                        ;is determined by a small delay loop
DELAY_LP2       DEX                             ;
                BNE DELAY_LP2                   ;
                DEY                             ;
                BNE DELAY_LP1                   ;
                RTS                             ;

LONG_DELAY      LDA #$10                        ;
                STA TMP_2                       ;
LONG_DELAY_01   JSR DELAY                       ;
                DEC TMP_2                       ;
                BNE LONG_DELAY_01               ;
                RTS                             ;
;------------------------------------------------------------------------------------------------------------------

;------------------------------------------------------------------------------------------------------------------
;This draws and decrements the timebar, when timer expires the Z-flag is cleared
;Call example:
;               JSR DELAY
;..................................................................................................................
TIMECOUNT_MAX = 23    ;

TIMEBAR_INIT    LDA #TIMECOUNT_MAX      ;
                STA TIMECOUNT           ;
                JSR TIMEBAR             ;
                RTS                     ;
                
                ;.......................

TIMEBAR         LDA #2                  ;0=black, 1=white, 2=red, 5=green, 6=blue, 7=yellow,  9=brown, etc.
                STA COL_PRINT           ;set printing color
                LDA #TIMECOUNT_MAX      ;
                STA TCNT_Y              ;

TIMEBAR_LP      LDX #36                 ;build the screen
                SEC                     ;
                LDA #TIMECOUNT_MAX+1    ;
                SBC TCNT_Y              ;
                TAY                     ;
                JSR SET_CURSOR          ;

                LDA TIMECOUNT           ;
                CMP TCNT_Y              ;
                BCC TIMEBAR_OFF         ;
TIMEBAR_ON      LDA #98                 ;"block" character is stored in Accumulator
                JMP TIMEBAR_SHOW        ;
TIMEBAR_OFF     LDA #32                 ;"space" character is stored in Accumulator
                JMP TIMEBAR_SHOW        ;

TIMEBAR_SHOW    JSR PRINT_CHAR          ;character is printed to screen, cursor is incremented by one

                DEC TCNT_Y              ;
                BNE TIMEBAR_LP          ;              

                JSR SOUND_TICK          ;
                DEC TIMECOUNT           ;
                RTS                     ;

                ;........................

TIMECOUNT       BYTE $0
TCNT_Y          BYTE $0



;==================================================================================================================

SCREEN_GAME
; Screen 1 - Game_screen
        BYTE    $20,$20,$20,$55,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$72,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$49,$20,$20,$20,$20,$20,$20,$20,$55,$43,$49,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$42,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$55,$43,$43,$43,$71,$43,$43,$43,$49,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$5D,$20,$0C,$05,$16,$05,$0C,$20,$5D,$7B,$7B,$7B,$7B,$7B,$7B,$7B,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$6B,$43,$43,$43,$43,$43,$43,$43,$73,$20,$20,$20,$20,$20,$20,$20,$6B,$43,$43,$43,$43,$43,$43,$43,$73,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$5D,$20,$20,$2D,$2D,$2D,$20,$20,$5D,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$4A,$43,$43,$43,$72,$43,$43,$43,$4B,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$5D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$42,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$7E,$5D,$20,$20,$20,$20,$20,$20,$20,$5D,$20,$5D,$20,$20
        BYTE    $20,$20,$20,$4A,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$71,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$4B,$20,$20,$20,$20,$20,$20,$20,$4A,$43,$4B,$20,$20
        BYTE 0  ;end of table marker

SCREEN_DOCS
; Screen 2 - Screen_docs
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$09,$0E,$13,$14,$12,$15,$03,$14,$09,$0F,$0E,$13,$3A,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$14,$08,$05,$20,$0F,$02,$0A,$05,$03,$14,$20,$0F,$06,$20,$14,$08,$05,$20,$07,$01,$0D,$05,$20,$09,$13,$20,$14,$0F,$20,$12,$05,$10,$05,$01,$14,$20,$20,$20
        BYTE    $20,$20,$14,$08,$05,$20,$13,$05,$11,$15,$05,$0E,$03,$05,$20,$14,$08,$05,$20,$03,$0F,$0D,$10,$15,$14,$05,$12,$20,$13,$08,$0F,$17,$13,$20,$19,$0F,$15,$20,$20,$20
        BYTE    $20,$09,$06,$20,$19,$0F,$15,$20,$13,$15,$03,$03,$05,$05,$04,$2C,$20,$09,$14,$20,$07,$05,$14,$13,$20,$0D,$0F,$12,$05,$20,$04,$09,$06,$06,$09,$03,$15,$0C,$14,$21
        BYTE    $20,$20,$20,$20,$20,$20,$20,$09,$06,$20,$19,$0F,$15,$20,$06,$01,$09,$0C,$2C,$20,$14,$08,$05,$20,$07,$01,$0D,$05,$20,$05,$0E,$04,$13,$21,$20,$20,$20,$20,$20,$20
        BYTE    $20,$08,$0F,$17,$20,$07,$0F,$0F,$04,$20,$09,$13,$20,$19,$0F,$15,$12,$20,$0D,$05,$0D,$0F,$12,$19,$20,$15,$0E,$04,$05,$12,$20,$10,$12,$05,$13,$13,$15,$12,$05,$3F
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $13,$15,$10,$10,$0F,$12,$14,$05,$04,$20,$09,$0E,$10,$15,$14,$20,$04,$05,$16,$09,$03,$05,$13,$3A,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$77,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$2D,$20,$0C,$09,$07,$08,$14,$08,$01,$0D,$0D,$05,$12,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$2D,$20,$13,$14,$01,$03,$0B,$20,$0C,$09,$07,$08,$14,$20,$12,$09,$06,$0C,$05,$20,$28,$0F,$12,$20,$03,$0F,$0D,$10,$01,$14,$09,$02,$0C,$05,$29,$20,$20,$20,$20
        BYTE    $20,$2D,$20,$0D,$01,$07,$0E,$15,$0D,$20,$0C,$09,$07,$08,$14,$20,$10,$08,$01,$13,$05,$12,$20,$28,$0F,$12,$20,$03,$0F,$0D,$10,$01,$14,$09,$02,$0C,$05,$29,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$55,$43,$43,$43,$43,$43,$43,$43,$43,$43,$40,$40,$40,$40,$40,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$49,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$5D,$20,$06,$09,$12,$05,$2F,$08,$09,$14,$20,$3D,$20,$05,$18,$09,$14,$20,$14,$08,$09,$13,$20,$13,$03,$12,$05,$05,$0E,$20,$5D,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$4A,$43,$43,$43,$43,$43,$43,$43,$43,$43,$40,$40,$40,$40,$40,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$43,$4B,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$0D,$15,$13,$09,$03,$3A,$0D,$09,$07,$08,$14,$19,$20,$02,$0F,$0D,$02,$0A,$01,$03,$0B
        BYTE    $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$10,$12,$0F,$07,$12,$01,$0D,$0D,$09,$0E,$07,$3A,$0A,$01,$0E,$20,$04,$05,$12,$0F,$07,$05,$05
        BYTE 0  ;end of table marker
